import { AxiosInstance } from "axios";
export interface UnimplementedFields {
    /**
     * Support arbitrary keys (to make this type useful even when it has drifted from the real implementation)
     */
    [k: string]: unknown;
}
export interface UnimplementedRelationships {
    /**
     * Support arbitrary keys (to make this type useful even when it has drifted from the real implementation)
     */
    [k: string]: Relationship | RelationshipsArray | undefined;
}
export interface BaseListParams extends UnimplementedFields {
    /**
     * Maximum number of resources that will be returned. Maximum is 1000 resources. See Pagination.
     * default: 100
     */
    limit?: number;
    /**
     * Number of resources to skip. See Pagination.
     * default: 0
     */
    offset?: number;
}
export type Sort = "createdAt" | "-createdAt";
/**
 * See [Tags](https://developers.unit.co/#tags).
 * Inherited from the payment tags (see [Tag Inheritance](https://developers.unit.co/#tag-inheritance)).
 */
export type Tags = Record<string, string | null>;
export type Status = "Approved" | "Denied" | "PendingReview";
export type Title = "CEO" | "COO" | "CFO" | "President" | "BenefitsAdministrationOfficer" | "CIO" | "VP" | "AVP" | "Treasurer" | "Secretary" | "Controller" | "Manager" | "Partner" | "Member";
export type State = "AL" | "AK" | "AZ" | "AR" | "CA" | "CO" | "CT" | "DE" | "FL" | "GA" | "HI" | "ID" | "IL" | "IN" | "IA" | "KS" | "KY" | "LA" | "ME" | "MD" | "MA" | "MI" | "MN" | "MS" | "MO" | "MT" | "NE" | "NV" | "NH" | "NJ" | "NM" | "NY" | "NC" | "ND" | "OH" | "OK" | "OR" | "PA" | "RI" | "SC" | "SD" | "TN" | "TX" | "UT" | "VT" | "VA" | "WA" | "WV" | "WI" | "WY" | "AS" | "DC" | "FM" | "GU" | "MH" | "MP" | "PW" | "PR" | "VI";
export interface FullName {
    /**
     * 	Individual first name.
     */
    first: string;
    /**
     * 	Individual last name.
     */
    last: string;
}
export interface UsAddress {
    /**
     * First line of an address.
     */
    street: string;
    /**
     * Optional. Second line of an address.
     */
    street2?: string;
    /**
     * City
     */
    city: string;
    /**
     * Two letters representing the state. Only required for US addresses.
     */
    state: State;
    /**
     * Postal code.
     */
    postalCode: string;
    /**
     * Two letters representing the country.
     * ISO31661 - Alpha2 format. For more information: https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2
     */
    country: "US";
}
export interface InternationalAddress {
    street: string;
    street2?: string;
    city: string;
    state?: string;
    postalCode: string;
    country: string;
}
export type Address = UsAddress | InternationalAddress;
export interface Phone {
    /**
     * Country code of the phone number.
     */
    countryCode: string;
    /**
     * The phone number without the country code.
     */
    number: string;
}
export interface BaseContactAttributes extends UnimplementedFields {
    fullName: FullName;
    ssn?: string;
    /**
     * Date only. RFC3339 format. For more information: https://en.wikipedia.org/wiki/ISO_8601#RFCs
     */
    dateOfBirth: string;
    address: Address;
    phone: Phone;
    email: string;
}
export interface Officer extends BaseContactAttributes {
    /**
     * One of Approved, Denied or PendingReview.
     */
    status?: Status;
    /**
     * One of CEO, COO, CFO, President, BenefitsAdministrationOfficer, CIO, VP, AVP, Treasurer, Secretary, Controller, Manager, Partner or Member
     */
    title?: Title;
    /**
     * SSN of the officer (numbers only). One of ssn or passport is required.
     */
    ssn?: string;
    /**
     * Passport of the beneficial owner. One of ssn or passport is required.
     */
    passport?: string;
    /**
     * Only when Passport is populated. Two letters representing the officer's nationality.
     * ISO31661 - Alpha2 format. For more information: https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2
     */
    nationality?: string;
}
export type BusinessContact = {
    /**
    * Optional. See (this)[https://docs.unit.co/customer-api-tokens/#customers-create-customer-bearer-token-jwt] section for more information.
    */
    jwtSubject?: string;
} & Pick<BaseContactAttributes, "fullName" | "email" | "phone">;
export type AuthorizedUser = Pick<BaseContactAttributes, "fullName" | "email" | "phone"> & {
    /**
     * Optional. See (this)[https://docs.unit.co/customer-api-tokens/#customers-create-customer-bearer-token-jwt] section for more information.
     */
    jwtSubject?: string;
};
export interface Counterparty {
    /**
     * Valid 9-digit ABA routing transit number.
     */
    routingNumber: string;
    /**
     * Bank account number.
     */
    accountNumber: string;
    /**
     * Either Checking or Savings.
     */
    accountType: string;
    /**
     * Name of the person or company that owns the bank account.
     */
    name: string;
    /**
     * Optional. See (this)[https://docs.unit.co/customer-api-tokens/#customers-create-customer-bearer-token-jwt] section for more information.
     */
    jwtSubject?: string;
}
export interface WireCounterparty extends Pick<Counterparty, "routingNumber" | "accountNumber" | "name"> {
    /**
     * Address of the person or company that owns the bank account.
     */
    address: Address;
}
export type CheckCounterparty = Pick<Counterparty, "routingNumber" | "accountNumber" | "name">;
export interface CheckPaymentCounterparty {
    /**
     * The name of the person or company that owns the bank account.
     */
    name: string;
    /**
     * The payee's address. street length cannot exceeed 50 characters. street2 must be null`.
     */
    address: Address;
    /**
     * Optional. True if the counterparty's address has been modified to correspond with a National Change of Address applied on the address. See guide for further information.
     */
    counterpartyMoved?: boolean;
}
export interface Coordinates {
    /**
     * The longitude value.
     */
    longitude: number | string;
    /**
     * The latitude value.
     */
    latitude: number | string;
}
export interface Statement {
    /**
     * Identifier of the statement resource.
     */
    id: string;
    /**
     * Type of the statement resource. The value is always statement.
     */
    type: "statement";
    /**
     * JSON object representing the statement data.
     */
    attributes: {
        /**
         * Period of the statement, formatted YYYY-MM, e.g "2020-05".
         */
        period: string;
    } & UnimplementedFields;
    /**
     * Describes relationships between the statement resource and other resources (account and customer).
     */
    relationships: {
        /**
         * The account for which the statement was produced.
         */
        account: Relationship;
        /**
         * The individual or business customer the account belongs to.
         */
        customer?: Relationship;
        /**
         * The list of Customers the deposit account belongs to. This relationship is only available if the account belongs to multiple individual customers.
         */
        customers?: RelationshipsArray;
    } & UnimplementedRelationships;
}
type R = {
    type: string;
    id: string;
};
/**
 * More about [Relationship](https://developers.unit.co/#relationships)
 */
export type Relationship = {
    data: R;
};
export type RelationshipsArray = {
    data: RelationshipsArrayData;
};
export type RelationshipsArrayData = Array<R>;
/**
 * More about [DeviceFingerprint](https://developers.unit.co/types#devicefingerprint)
 */
export interface DeviceFingerprint {
    /**
     * Provider of the device fingerprint fraud and risk prevention. The value is always iovation
     */
    provider: string;
    /**
     * The device fingerprint blackbox value.
     */
    value: string;
}
/**
 * More about [Agent](https://docs.unit.co/types/#agent)
 */
export interface Agent extends BaseContactAttributes {
    /**
     * One of Approved, Denied or PendingReview.
     */
    status: Status;
    /**
     * Passport of the agent. One of ssn or passport is required.
     */
    passport?: string;
    /**
     * ISO31661-Alpha2 string	Only when Passport is populated. Two letters representing the agent's nationality.
     */
    nationality?: string;
    /**
     * Optional. See [this](https://docs.unit.co/customer-api-tokens/#customers-create-customer-bearer-token-jwt) section for more information.
     */
    jwtSubject?: string;
}
export interface Merchant {
    /**
     * The name of the merchant.
     */
    name?: string;
    /**
     * The 4-digit ISO 18245 merchant category code (MCC).
     */
    type?: number;
    /**
     * The merchant category, described by the MCC code (see [this reference](https://github.com/greggles/mcc-codes) for the list of category descriptions).
     */
    category?: string;
    /**
     * Optional. The location (city, state, etc.) of the merchant.
     */
    location?: string;
    /**
     * Optional. The unique network merchant identifier.
     */
    id?: string;
}
export interface HealthcareAmounts {
    /**
     * Dental expense (cents).
     */
    dentalAmount: number;
    /**
     * Transit expense (cents).
     */
    transitAmount: number;
    /**
     * Vision expense (cents).
     */
    visionOpticalAmount: number;
    /**
     * Prescription drugs expense (cents).
     */
    prescriptionRXAmount: number;
    /**
     * Misc medical expense (cents).
     */
    clinicOtherQualifiedMedicalAmount: number;
    /**
     * Total medical expense (cents).
     */
    totalHealthcareAmount: number;
}
export interface EvaluationParams {
    /**
     * Optional. Decide when to request a selfie verification document
     */
    useSelfieVerification?: "Never" | "ReplaceIdentification" | "Always";
    /**
     * Optional, default to false. Decide whether to require an ID verification regardless of evaluation response
     */
    requireIdVerification?: boolean;
}
export type Industry = "Retail" | "Wholesale" | "Restaurants" | "Hospitals" | "Construction" | "Insurance" | "Unions" | "RealEstate" | "FreelanceProfessional" | "OtherProfessionalServices" | "OnlineRetailer" | "OtherEducationServices";
export type Direction = "Credit" | "Debit";
export type CardNetwork = "Visa" | "Interlink" | "Accel" | "Allpoint" | "Other";
export type EntityType = "Corporation" | "LLC" | "Partnership" | "PubliclyTradedCorporation" | "PrivatelyHeldCorporation" | "NotForProfitOrganization";
export interface RichMerchantData {
    name: string;
    website?: string;
    logo?: string;
    phone?: string;
    categories?: Array<{
        name: string;
        icon: string;
    }>;
    address?: {
        city: string;
        state: string;
        country: string;
        street?: string;
    };
    coordinates?: Coordinates;
    facilitators?: Array<RichMerchantDataFacilitator>;
}
export interface RichMerchantDataFacilitator {
    name: string;
    type?: "BuyNowPayLater" | "DeliveryService" | "Marketplace" | "PaymentProcessor" | "Platform" | "PointOfSale";
    logo?: string;
}
export interface CurrencyConversion {
    originalCurrency: string;
    amountInOriginalCurrency: number;
    fxRate?: string;
}
export interface UnitResponse<T> {
    data: T;
}
export type NoContent = "";
export interface Include<T> {
    included?: T;
}
export interface Meta extends UnimplementedFields {
    /**
     * JSON object that contains pagination data
     */
    meta: {
        pagination: {
            total: number;
            limit: number;
            offset: number;
        };
    };
}
export interface BaseCreateRequestAttributes {
    /**
     * See [Tags](https://developers.unit.co/#tags).
     */
    tags?: Tags;
    /**
     * See [Idempotency.](https://developers.unit.co/#intro-idempotency)
     */
    idempotencyKey?: string;
}
export declare enum ApiVersion {
    V2024_06 = "V2024_06"
}
export interface UnitConfig {
    axios?: AxiosInstance;
    sdkUserAgent?: boolean;
    securePath?: string;
    apiVersion?: ApiVersion | string;
}
export declare class UnitError extends Error {
    readonly isUnitError = true;
    readonly underlying: any;
    readonly errors: UnitErrorPayload[];
    constructor(message: string, underlying?: any, errors?: UnitErrorPayload[]);
}
export interface UnitErrorPayload {
    status: string;
    title: string;
    code?: string;
    detail?: string;
    details?: string;
    meta?: {
        supportId?: string;
        existingIds?: string[];
    };
    source?: {
        pointer: string;
    };
    [k: string]: unknown;
}
export declare const extractUnitError: (underlying: any) => UnitError;
export type Interval = "Monthly" | "Weekly";
interface BaseSchedule {
    /**
     * RFC3339 format. For more information: https://en.wikipedia.org/wiki/ISO_8601#RFCs
     * Optional. Start time of the recurring payment. Date only (e.g. "2022-06-29")
     */
    startTime?: string;
    /**
     * RFC3339 format. For more information: https://en.wikipedia.org/wiki/ISO_8601#RFCs
     * Optional. End time of the recurring payment. Date only (e.g. "2022-10-29 ")
     */
    endTime?: string;
    /**
     * Optional. Scheduled day time in the month. Valid values can be between 1-28 or (-5)-(-1).
     * Negative numbers represent relative day to the end of the month. -1 represents the last day of the month.
     */
    dayOfMonth?: number;
    /**
     * Interval of the schedule. Can be Monthly.
     */
    interval?: Interval;
    /**
     * Scheduled day of the week. Required when Weekly interval is specified.
     * Valid values are Sunday, Monday, Tuesday, Wednesday, Thursday, Friday, Saturday.
     */
    dayOfWeek?: "Sunday" | "Monday" | "Tuesday" | "Wednesday" | "Thursday" | "Friday" | "Saturday";
    /**
     * Optional. Total number of payment repetitions. Positive integers only.
     */
    totalNumberOfPayments?: number;
}
export type CreateSchedule = BaseSchedule;
export interface Schedule extends BaseSchedule {
    /**
     * RFC3339 format. For more information: https://en.wikipedia.org/wiki/ISO_8601#RFCs
     * The next scheduled date of the action.
     */
    nextScheduledAction: string;
}
export type QueryParameters = Record<string, number | string | boolean>;
export {};
